@@ -133,7 +133,7 @@ DECLARE_BUILTIN_FUNCTION(ShiftFunction)
 DECLARE_BUILTIN_FUNCTION_R(AbsFunction)
 DECLARE_BUILTIN_FUNCTION(GcdFunction)
 DECLARE_BUILTIN_FUNCTION(LcmFunction)
-DECLARE_BUILTIN_FUNCTION(SignumFunction)
+DECLARE_BUILTIN_FUNCTION_R(SignumFunction)
 DECLARE_BUILTIN_FUNCTION_R(RoundFunction)
 DECLARE_BUILTIN_FUNCTION_R(FloorFunction)
 DECLARE_BUILTIN_FUNCTION_R(CeilFunction)
@@ -156,9 +156,13 @@ DECLARE_BUILTIN_FUNCTION(LDegreeFunction)
 
 DECLARE_BUILTIN_FUNCTION_R(ReFunction)
 DECLARE_BUILTIN_FUNCTION_R(ImFunction)
-DECLARE_BUILTIN_FUNCTION(ArgFunction)
+DECLARE_BUILTIN_FUNCTION_R2(ArgFunction)
 
-DECLARE_BUILTIN_FUNCTION(SqrtFunction)
+DECLARE_BUILTIN_FUNCTION(IntervalFunction)
+
+DECLARE_BUILTIN_FUNCTION_R(SqrtFunction)
+DECLARE_BUILTIN_FUNCTION(CbrtFunction)
+DECLARE_BUILTIN_FUNCTION_R(RootFunction)
 DECLARE_BUILTIN_FUNCTION(SquareFunction)
 
 DECLARE_BUILTIN_FUNCTION(ExpFunction)
@@ -268,6 +272,4 @@ DECLARE_BUILTIN_FUNCTION(SolveMultipleFunction)
 
 DECLARE_BUILTIN_FUNCTION(PlotFunction)
 
-DECLARE_BUILTIN_FUNCTION(UncertaintyFunction)
-
 #endif
