@@ -208,6 +208,8 @@ class Calculator {
 
 	int ianglemode;
 	int i_precision;
+	bool b_interval;
+	int i_stop_interval;
 	char vbuffer[200];
 	vector<void*> ufvl;
 	vector<char> ufvl_t;
@@ -219,10 +221,10 @@ class Calculator {
 	
 	class Calculator_p *priv;
 	
-	vector<string> signs;	
+	vector<string> signs;
 	vector<string> real_signs;
-	vector<string> default_signs;	
-	vector<string> default_real_signs;	
+	vector<string> default_signs;
+	vector<string> default_real_signs;
 	char *saved_locale;
 	int disable_errors_ref;
 	vector<int> stopped_errors_count;
@@ -251,6 +253,8 @@ class Calculator {
 	vector<MathFunction*> deleted_functions;
 	vector<Unit*> deleted_units;
 	
+	bool b_var_units;
+	
 	bool b_save_called;
 	
 	int i_timeout;
@@ -268,7 +272,7 @@ class Calculator {
 	
   public:
 
-	KnownVariable *v_pi, *v_e, *v_euler, *v_catalan, *v_i, *v_inf, *v_pinf, *v_minf, *v_undef, *v_precision;
+	KnownVariable *v_pi, *v_e, *v_euler, *v_catalan, *v_i, *v_pinf, *v_minf, *v_undef, *v_precision;
 	UnknownVariable *v_x, *v_y, *v_z;
 	MathFunction *f_vector, *f_sort, *f_rank, *f_limits, *f_component, *f_dimension, *f_merge_vectors;
 	MathFunction *f_matrix, *f_matrix_to_vector, *f_area, *f_rows, *f_columns, *f_row, *f_column, *f_elements, *f_element, *f_transpose, *f_identity, *f_determinant, *f_permanent, *f_adjoint, *f_cofactor, *f_inverse; 
@@ -276,8 +280,8 @@ class Calculator {
 	MathFunction *f_xor, *f_bitxor, *f_even, *f_odd, *f_shift;
 	MathFunction *f_abs, *f_gcd, *f_lcm, *f_signum, *f_round, *f_floor, *f_ceil, *f_trunc, *f_int, *f_frac, *f_rem, *f_mod;	
 	MathFunction *f_polynomial_unit, *f_polynomial_primpart, *f_polynomial_content, *f_coeff, *f_lcoeff, *f_tcoeff, *f_degree, *f_ldegree;
-	MathFunction *f_re, *f_im, *f_arg, *f_numerator, *f_denominator;
-  	MathFunction *f_sqrt, *f_sq;
+	MathFunction *f_re, *f_im, *f_arg, *f_numerator, *f_denominator, *f_interval;
+  	MathFunction *f_sqrt, *f_cbrt, *f_root, *f_sq;
 	MathFunction *f_exp;
 	MathFunction *f_ln, *f_logn;
 	MathFunction *f_lambert_w;
@@ -294,15 +298,15 @@ class Calculator {
 	MathFunction *f_error, *f_warning, *f_message, *f_save, *f_load, *f_export, *f_title;
 	MathFunction *f_register, *f_stack;
 	MathFunction *f_plot;
-	MathFunction *f_uncertainty;
 	
-	Unit *u_rad, *u_gra, *u_deg, *u_euro;
+	Unit *u_rad, *u_gra, *u_deg, *u_euro, *u_btc;
 	DecimalPrefix *decimal_null_prefix;
 	BinaryPrefix *binary_null_prefix;
 
   	bool place_currency_code_before, place_currency_sign_before;
 	bool place_currency_code_before_negative, place_currency_sign_before_negative;
 	bool default_dot_as_separator;
+	string local_digit_group_separator, local_digit_group_format;
   
   	bool b_busy;
 	string expression_to_calculate;
@@ -602,7 +606,7 @@ class Calculator {
 	bool separateToExpression(string &str, string &to_str, const EvaluationOptions &eo, bool keep_modifiers = false) const;	
 	bool hasToExpression(const string &str) const;
 
-	void parseSigns(string &str) const;
+	void parseSigns(string &str, bool convert_to_internal_representation = false) const;
 	/** Parse an expression and place in a MathStructure object.
 	*
 	* @param str Expression
@@ -851,6 +855,9 @@ class Calculator {
 	/** Adds builtin units. Called automatically when the calculator is created. */
 	void addBuiltinUnits();
 	//@}
+	
+	void setVariableUnitsEnabled(bool enable_variable_units = true);
+	bool variableUnitsEnabled() const;
 
 	/** @name Functions for testing validity of functions, variable and unit names. */
 	//@{
@@ -910,7 +917,7 @@ class Calculator {
 	CalculatorMessage *nextMessage();
 	bool showArgumentErrors() const;
 	void beginTemporaryStopMessages();
-	int endTemporaryStopMessages(int *message_count = NULL, int *warning_count = NULL);	
+	int endTemporaryStopMessages(int *message_count = NULL, int *warning_count = NULL);
 	//@}
 
 	/** @name Functions for loading and saving definitions (variables, functions, units, etc.). */
@@ -1006,15 +1013,19 @@ class Calculator {
 	*/
 	bool loadExchangeRates();
 	/** Name of the exchange rates file on local disc.
+	* Multiple exchange rates sources might be used. Iterate over these, using the index parameter, until an empty string is returned.
 	*
+	* @param index The index (starting at one) of the exchange rate source
 	* @returns name of local exchange rates file.
 	*/
-	string getExchangeRatesFileName();
+	string getExchangeRatesFileName(int index = 1);
 	/** Url of the exchange rates file on the Internet.
+	* Multiple exchange rates sources might be used. Iterate over these, using the index parameter, until an empty string is returned.
 	*
+	* @param index The index (starting at one) of the exchange rate source
 	* @returns Url of exchange rates file.
 	*/
-	string getExchangeRatesUrl();
+	string getExchangeRatesUrl(int index = 1);
 	/** Modification time of the exchange rates file.
 	*
 	* @returns Returns exchange rates modification time.
@@ -1074,6 +1085,16 @@ class Calculator {
 	/** Returns default precision for approximate calculations.
 	*/
 	int getPrecision() const;
+	/** Set if interval arithmetic should be used for approximate calculations.
+	*
+	* @param use_interval_arithmetic Set true to activate, or false to deactivate, interval arithmetic.
+	*/
+	void useIntervalArithmetic(bool use_interval_arithmetic = true);
+	/** Returns true if interval arithmetic are activated.
+	*/
+	bool usesIntervalArithmetic() const;
+	void beginTemporaryStopIntervalArithmetic();
+	void endTemporaryStopIntervalArithmetic();
 	//@}
 
 	/** @name Functions for localization */
@@ -1082,7 +1103,7 @@ class Calculator {
 	*/
 	const string &getDecimalPoint() const;
 	/** Returns the preferred comma character for separating arguments.*/
-	const string &getComma() const;	
+	const string &getComma() const;
 	/** Sets argument separator and decimal sign from the current locale. Mainly for internal use. */
 	void setLocale();
 	void useDecimalComma();
@@ -1149,6 +1170,14 @@ class QalculateDate {
 		QalculateDate(long int initialyear, int initialmonth, int initialday);
 		QalculateDate(long int initialtimestamp);
 		QalculateDate(string date_string);
+		bool operator > (const QalculateDate &date2) const;
+		bool operator < (const QalculateDate &date2) const;
+		bool operator >= (const QalculateDate &date2) const;
+		bool operator <= (const QalculateDate &date2) const;
+		bool operator != (const QalculateDate &date2) const;
+		bool operator == (const QalculateDate &date2) const;
+		bool isFutureDate() const;
+		bool isPastDate() const;
 		void setToCurrentDate();
 		bool set(long int newyear, int newmonth, int newday);
 		bool set(long int newtimestamp);
